@@ -7,9 +7,9 @@ __all__ = ["Query"]
 
 class Query(object):
     @staticmethod
-    def __get_pd_by_parquet_file(url):
+    def __get_pd_by_parquet_file(url, engine):
         r = requests.get(url)
-        return pd.read_parquet(BytesIO(r.content))
+        return pd.read_parquet(BytesIO(r.content), engine=engine)
 
     def __init__(
         self,
@@ -104,7 +104,7 @@ class Query(object):
         else:
             self.__get_sql_result_by_restful(limit, offset)
 
-    def __get_sql_result_by_storage(self, limit, offset):
+    def __get_sql_result_by_storage(self, limit, offset, engine='fastparquet'):
         limit = limit or self.limit
         offset = offset or self.offset
         query_id = self.id
@@ -118,7 +118,7 @@ class Query(object):
             dfs = []
             count = 0
             for url in urls:
-                df = self.__get_pd_by_parquet_file(url)
+                df = self.__get_pd_by_parquet_file(url, engine)
                 count += df.shape[0]
                 dfs.append(df)
                 # if we get enough data, stop getting the next one
